Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(820)

Unified Diff: test/must_pub_get_test.dart

Issue 1956543002: Fix a lockfile freshness checking bug. (Closed) Base URL: git@github.com:dart-lang/pub.git@master
Patch Set: Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « lib/src/package.dart ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: test/must_pub_get_test.dart
diff --git a/test/must_pub_get_test.dart b/test/must_pub_get_test.dart
index 058ea89ae27e0681a29eb83ecb80902d80e91753..0381c5bbb3e1c9a6518115b9c249f953ea91e25a 100644
--- a/test/must_pub_get_test.dart
+++ b/test/must_pub_get_test.dart
@@ -293,16 +293,19 @@ foo:http://example.com/
]).create();
d.dir(appPath, [
- d.appPubspec({"foo": {"path": "../foo"}})
- ]);
+ d.appPubspec({"bar": {"path": "../bar"}})
+ ]).create();
pubGet();
// Update foo's pubspec without touching the app's.
d.dir("bar", [
d.libPubspec("bar", "1.0.0", deps: {"foo": "2.0.0"})
]).create();
});
+
+ _requiresPubGet('The pubspec.yaml file has changed since the '
+ 'pubspec.lock file was generated, please run "pub get" again.');
Bob Nystrom 2016/05/05 22:06:42 It would be really nice if the error message showe
nweiz 2016/05/05 22:29:49 Done.
});
@@ -293,16 +293,19 @@ foo:http://example.com/
pubGet();
- // Update foo's pubspec without touching the app's.
+ // Update bar's pubspec without touching the app's.
d.dir("bar", [
d.libPubspec("bar", "1.0.0", deps: {"foo": "2.0.0"})
});
« no previous file with comments | « lib/src/package.dart ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698